@@ -12,29 +12,6 @@ try:
 except ImportError:
     from typing_extensions import Optional
 
-ALLOWED_PII_CLASSES = [
-    "DATE_TIME",
-    "LOCATION",
-    "NUMBER",
-    "LANGUAGE",
-    "LAW",
-    "MONEY",
-    "NORP",
-    "ORGANIZATION",
-    "PERSON",
-    "PRODUCT",
-    "WORK_OF_ART",
-    "EVENT",
-    "PASSPORT",
-    "CREDIT_CARD",
-    "EMAIL_ADDRESS",
-    "IBAN_CODE",
-    "IP_ADDRESS",
-    "PHONE_NUMBER",
-    "CRYPTO_NUMBER",
-    "SSN_NUMBER",
-]
-
 ALLOWED_EXTRACTION_PROMPTS = [
     None,
     "",
@@ -128,14 +105,7 @@ class Helpers:
         return payload
 
     @staticmethod
-    def validate_pii_inputs(
-        pii_classes: Optional[List[str]] = None, regex_expressions: Optional[Dict[str, str]] = None
-    ):
-        if pii_classes is not None:
-            for pii_class in pii_classes:
-                if pii_class not in ALLOWED_PII_CLASSES:
-                    raise ValueError(f"Invalid PII class: {pii_class}")
-
+    def validate_pii_inputs(regex_expressions: Optional[Dict[str, str]] = None):
         if regex_expressions is not None:
             for pattern in regex_expressions.values():
                 try:
