@@ -5,6 +5,7 @@ handles error logging and response parsing.
 """
 import json
 import logging
+from enum import Enum
 
 import requests
 
@@ -19,6 +20,13 @@ def _check_for_error(r):
     r.raise_for_status()
 
 
+class CustomEnumEncoder(json.JSONEncoder):
+    def default(self, o):
+        if isinstance(o, Enum):
+            return o.value
+        return super().default(o)
+
+
 class _Request:
     """
     Handles HTTP requests with Bearer token authentication.
@@ -46,7 +54,27 @@ class _Request:
 
     def _log_error(self, response):
         if not response.ok:
-            logger.error(json.dumps(json.loads(response.text), indent=4))
+            try:
+                logger.error(json.dumps(json.loads(response.text), indent=4))
+            except json.JSONDecodeError:
+                logger.error(response.text)
+
+    def _prepare_payload(self, payload):
+        """
+        Prepares the payload for serialization by converting it to a JSON-compatible format.
+
+        This method takes a payload, serializes it using a custom JSON encoder for Enums,
+        and then deserializes it back into a Python object. This is useful for ensuring that
+        the payload can be correctly sent in an HTTP request.
+
+        Args:
+            payload (Any): The payload to be prepared, which can include various data types.
+
+        Returns:
+            Any: The JSON-compatible representation of the payload.
+        """
+        data = json.loads(json.dumps(payload, cls=CustomEnumEncoder))
+        return data
 
     def _make_request(
         self,
@@ -73,7 +101,9 @@ class _Request:
             response = request_method(
                 f"{self._get_route()}{url}",
                 headers=self._get_headers(),
-                json=params if method in ["POST", "DELETE", "PATCH", "PUT"] else None,
+                json=self._prepare_payload(params)
+                if method in ["POST", "DELETE", "PATCH", "PUT"]
+                else None,
                 params=params if method == "GET" else None,
                 files=files,
                 verify=False,
