@@ -5,6 +5,8 @@ from importlib import import_module
 from time import sleep
 from typing import Any, Callable, Dict, List, Union
 
+import requests
+
 from .api.DatasourceAPI import DatasourceAPI
 from .api.ProjectAPI import ProjectAPI
 from .Datasource import _Datasource
@@ -493,6 +495,20 @@ class _State:
         )
         return self._get_model_entity_from_model_response(res)
 
+    def get_version(self) -> str | None:
+        try:
+            res = self.request._make_request(  # pylint: disable=protected-access
+                "GET", "/version", print_error=False
+            )
+            if not res:
+                raise Exception("Version API returned successfully but no response body")
+            return res["version"]
+        except requests.exceptions.HTTPError as e:
+            if e.response.status_code == 404:
+                return None
+            else:
+                raise e
+
 
 def get_federated_path(project_key, base, ext, ds, round_num):
     return f"{base}/federated_model_{project_key}_{ds}_{round_num}.{ext}"
