@@ -18,7 +18,7 @@ class Model:
         name: str,
         key: str,
         model_type: str,
-        model_id: str = None,
+        model_id: Optional[str] = None,
         config: object = {},
     ) -> None:
         self.key = key
