@@ -6,6 +6,7 @@ from typing import Any, Dict, List, Literal, Union
 
 from .api.billing import BillingAPI
 from .api.custom_rag_app import CustomRagAPI
+from .compatibility_engine import CompatibilityEngine
 from .datasets.dataset import Dataset
 from .datasets.hf_dataset import HFDataset
 from .entities.billing import BillingReport
@@ -21,7 +22,7 @@ from .entities.dataset import HFDatasetEntity
 from .entities.model import LocalModelEntity, RemoteModelEntity
 from .entities.test import TestEntity
 from .Helpers import Helpers, URLUtils
-from .logging import set_logger
+from .logging_v2 import set_logger
 from .MessageHandler import _MessageHandler
 from .models import local_model, remote_model
 from .State import _State
@@ -65,6 +66,8 @@ class DynamoFL:
             self._messagehandler.connect_to_ws()
 
         set_logger(log_level=log_level)
+        self._compatibility_engine = CompatibilityEngine()
+        self._compatibility_engine.validate_version_compatibility(self._state.get_version())
 
     def attach_datasource(self, key, train=None, test=None, name=None, metadata=None):
         return self._state.attach_datasource(
@@ -139,7 +142,6 @@ class DynamoFL:
         grid: List[Dict[str, List[Union[str, float, int]]]] = [{}],
     ) -> TestEntity:
         """Creates a performance test on a model with a dataset
-
         Args:
             name (str): Name of the test
             model_key (str): Key of the model to be tested
@@ -152,7 +154,6 @@ class DynamoFL:
             prompts_column (Optional[str]): Column to specify the prompts for the input
             reference_column (Optional[str]): Column to specify the reference for the input
             grid (List[Dict[str, List[str |  float  |  int]]]): Grid of hyper parameters
-
         Returns:
             TestEntity: TestEntity object
         """
@@ -210,7 +211,7 @@ class DynamoFL:
             TestEntity: TestEntity object
         """
 
-        Helpers.validate_pii_inputs(pii_classes, regex_expressions)
+        Helpers.validate_pii_inputs(regex_expressions)
 
         common_attack_config = {
             "attack": Helpers.construct_dict_filtering_none_values(
@@ -237,6 +238,125 @@ class DynamoFL:
             gpu=gpu,
         )
 
+    def create_pii_inference_test(  # pylint: disable=dangerous-default-value
+        self,
+        name: str,
+        model_key: str,
+        dataset_id: str,
+        gpu: GPUSpecification,
+        pii_ref_column: str,
+        pii_classes: Optional[List[str]] = None,
+        num_targets: Optional[int] = None,
+        candidate_size: Optional[int] = None,
+        regex_expressions: Optional[Dict[str, str]] = None,
+        prompts_column: Optional[str] = None,
+        sample_and_shuffle: Optional[int] = None,
+        grid: List[Dict[str, List[Union[str, float, int]]]] = [{}],
+    ) -> TestEntity:
+        """Create a pii inference test on a model with a dataset
+        Args:
+            name (str): Name of the test
+            model_key (str): Key of the model to be tested
+            dataset_id (str): Id of the dataset to be used
+            gpu (GPUSpecification): GPU specification
+            pii_ref_column (str): Column in the dataset to sample prompts from
+            pii_classes (Optional[List[str]]): PII classes to attack. E.g PERSON
+            num_targets (int): Number of target sequence to sample to attack
+            candidate_size (int): Number of PII candidates to sample randomly for the attack.
+            regex_expressions (Optional[Dict[str, str]]): list of regex expressions to use
+                for extraction
+            prompts_column (Optional[str]): Column to specify the prompts for the input.
+                Used for seq2seq models only.
+            sample_and_shuffle (int): number of times to sample and shuffle candidates
+            grid (List[Dict[str, List[str |  float  |  int]]]): Grid of hyper parameters
+        Returns:
+            TestEntity: TestEntity object
+        """
+
+        Helpers.validate_pii_inputs(regex_expressions)
+
+        common_attack_config = {
+            "attack": Helpers.construct_dict_filtering_none_values(
+                pii_classes=pii_classes,
+                num_targets=num_targets,
+                candidate_size=candidate_size,
+                regex_expressions=regex_expressions,
+                sample_and_shuffle=sample_and_shuffle,
+            ),
+            "dataset": Helpers.construct_dict_filtering_none_values(
+                column_name=pii_ref_column, prompts_column_name=prompts_column
+            ),
+        }
+
+        return Test.create_test_with_grid(
+            common_attack_config=common_attack_config,
+            grid=grid,
+            request=self._state.request,
+            name=name,
+            model_key=model_key,
+            dataset_id=dataset_id,
+            test_type="pii_inference",
+            gpu=gpu,
+        )
+
+    def create_pii_reconstruction_test(  # pylint: disable=dangerous-default-value
+        self,
+        name: str,
+        model_key: str,
+        dataset_id: str,
+        gpu: GPUSpecification,
+        pii_ref_column: str,
+        pii_classes: Optional[List[str]] = None,
+        num_targets: Optional[int] = None,
+        candidate_size: Optional[int] = None,
+        sampling_rate: Optional[float] = None,
+        regex_expressions: Optional[Dict[str, str]] = None,
+        grid: List[Dict[str, List[Union[str, float, int]]]] = [{}],
+    ) -> TestEntity:
+        """Create a pii reconstruction test on a model with a dataset
+        Args:
+            name (str): Name of the test
+            model_key (str): Key of the model to be tested
+            dataset_id (str): Id of the dataset to be used
+            gpu (GPUSpecification): GPU specification
+            pii_ref_column (str): Column in the dataset to sample prompts from
+            pii_classes (Optional[List[str]]): PII classes to attack. E.g PERSON
+            num_targets (int): Number of target sequence to sample to attack
+            candidate_size (int): Number of PII candidates to sample randomly for the attack.
+                Ranks PII candidates based on highest likelihood and selects top
+                candidate.
+            sampling_rate (Optional[float]): The number of times we prompt the model during a test.
+            regex_expressions (Optional[Dict[str, str]]): list of regex expressions to use
+                for extraction
+            grid (List[Dict[str, List[str |  float  |  int]]]): Grid of hyper parameters
+        Returns:
+            TestEntity: TestEntity object
+        """
+
+        Helpers.validate_pii_inputs(regex_expressions)
+
+        common_attack_config = {
+            "attack": Helpers.construct_dict_filtering_none_values(
+                pii_classes=pii_classes,
+                num_targets=num_targets,
+                candidate_size=candidate_size,
+                sampling_rate=sampling_rate,
+                regex_expressions=regex_expressions,
+            ),
+            "dataset": Helpers.construct_dict_filtering_none_values(column_name=pii_ref_column),
+        }
+
+        return Test.create_test_with_grid(
+            common_attack_config=common_attack_config,
+            grid=grid,
+            request=self._state.request,
+            name=name,
+            model_key=model_key,
+            dataset_id=dataset_id,
+            test_type="pii_reconstruction",
+            gpu=gpu,
+        )
+
     def create_hallucination_test(  # pylint: disable=dangerous-default-value
         self,
         name: str,
@@ -298,7 +418,6 @@ class DynamoFL:
         dataset_id: str,
         gpu: GPUSpecification,
         pii_ref_column: str,
-        base_model: Optional[str] = None,
         pii_classes: Optional[List[str]] = None,
         extraction_prompt: Optional[str] = None,
         sampling_rate: Optional[float] = None,
@@ -314,7 +433,6 @@ class DynamoFL:
             model_key (str): Key of the model to be tested
             dataset_id (str): Id of the dataset to be used
             gpu (GPUSpecification): GPU specification
-            base_model (Optional[str]): Base model to use for the attack
             pii_classes (Optional[List[str]]): PII classes to attack. E.g PERSON
             extraction_prompt (Optional[str]): Prompt for PII extraction. Can be '' (empty string),
             or one of the pre-defined strategies: 'dfl_dynamic', 'dfl_ata'
@@ -330,7 +448,7 @@ class DynamoFL:
             TestEntity: TestEntity object
         """
 
-        Helpers.validate_pii_inputs(pii_classes, regex_expressions)
+        Helpers.validate_pii_inputs(regex_expressions)
         Helpers.validate_extraction_prompt(extraction_prompt)
 
         common_attack_config = {
@@ -340,9 +458,6 @@ class DynamoFL:
                 sampling_rate=sampling_rate,
                 regex_expressions=regex_expressions,
             ),
-            "model": Helpers.construct_dict_filtering_none_values(
-                base_model=base_model,
-            ),
             "dataset": Helpers.construct_dict_filtering_none_values(
                 column_name=pii_ref_column,
                 prompts_column_name=prompts_column,
@@ -361,139 +476,6 @@ class DynamoFL:
             gpu=gpu,
         )
 
-    def create_pii_inference_test(  # pylint: disable=dangerous-default-value
-        self,
-        name: str,
-        model_key: str,
-        dataset_id: str,
-        gpu: GPUSpecification,
-        pii_ref_column: str,
-        base_model: Optional[str] = None,
-        pii_classes: Optional[List[str]] = None,
-        num_targets: Optional[int] = None,
-        candidate_size: Optional[int] = None,
-        regex_expressions: Optional[Dict[str, str]] = None,
-        prompts_column: Optional[str] = None,
-        sample_and_shuffle: Optional[int] = None,
-        grid: List[Dict[str, List[Union[str, float, int]]]] = [{}],
-    ) -> TestEntity:
-        """Create a pii inference test on a model with a dataset
-
-        Args:
-            name (str): Name of the test
-            model_key (str): Key of the model to be tested
-            dataset_id (str): Id of the dataset to be used
-            gpu (GPUSpecification): GPU specification
-            pii_ref_column (str): Column in the dataset to sample prompts from
-            base_model (Optional[str]): Base model to use for the attack
-            pii_classes (Optional[List[str]]): PII classes to attack. E.g PERSON
-            num_targets (int): Number of target sequence to sample to attack
-            candidate_size (int): Number of PII candidates to sample randomly for the attack.
-            regex_expressions (Optional[Dict[str, str]]): list of regex expressions to use
-                for extraction
-            prompts_column (Optional[str]): Column to specify the prompts for the input.
-                Used for seq2seq models only.
-            sample_and_shuffle (int): number of times to sample and shuffle candidates
-            grid (List[Dict[str, List[str |  float  |  int]]]): Grid of hyper parameters
-
-        Returns:
-            TestEntity: TestEntity object
-        """
-
-        Helpers.validate_pii_inputs(pii_classes, regex_expressions)
-
-        common_attack_config = {
-            "attack": Helpers.construct_dict_filtering_none_values(
-                pii_classes=pii_classes,
-                num_targets=num_targets,
-                candidate_size=candidate_size,
-                regex_expressions=regex_expressions,
-                sample_and_shuffle=sample_and_shuffle,
-            ),
-            "model": Helpers.construct_dict_filtering_none_values(
-                base_model=base_model,
-            ),
-            "dataset": Helpers.construct_dict_filtering_none_values(
-                column_name=pii_ref_column, prompts_column_name=prompts_column
-            ),
-        }
-
-        return Test.create_test_with_grid(
-            common_attack_config=common_attack_config,
-            grid=grid,
-            request=self._state.request,
-            name=name,
-            model_key=model_key,
-            dataset_id=dataset_id,
-            test_type="pii_inference",
-            gpu=gpu,
-        )
-
-    def create_pii_reconstruction_test(  # pylint: disable=dangerous-default-value
-        self,
-        name: str,
-        model_key: str,
-        dataset_id: str,
-        gpu: GPUSpecification,
-        pii_ref_column: str,
-        base_model: Optional[str] = None,
-        pii_classes: Optional[List[str]] = None,
-        num_targets: Optional[int] = None,
-        candidate_size: Optional[int] = None,
-        sampling_rate: Optional[float] = None,
-        regex_expressions: Optional[Dict[str, str]] = None,
-        grid: List[Dict[str, List[Union[str, float, int]]]] = [{}],
-    ) -> TestEntity:
-        """Create a pii reconstruction test on a model with a dataset
-
-        Args:
-            name (str): Name of the test
-            model_key (str): Key of the model to be tested
-            dataset_id (str): Id of the dataset to be used
-            gpu (GPUSpecification): GPU specification
-            pii_ref_column (str): Column in the dataset to sample prompts from
-            base_model (Optional[str]): Base model to use for the attack
-            pii_classes (Optional[List[str]]): PII classes to attack. E.g PERSON
-            num_targets (int): Number of target sequence to sample to attack
-            candidate_size (int): Number of PII candidates to sample randomly for the attack.
-                Ranks PII candidates based on highest likelihood and selects top
-                candidate.
-            sampling_rate (Optional[float]): The number of times we prompt the model during a test.
-            regex_expressions (Optional[Dict[str, str]]): list of regex expressions to use
-                for extraction
-            grid (List[Dict[str, List[str |  float  |  int]]]): Grid of hyper parameters
-
-        Returns:
-            TestEntity: TestEntity object
-        """
-
-        Helpers.validate_pii_inputs(pii_classes, regex_expressions)
-
-        common_attack_config = {
-            "attack": Helpers.construct_dict_filtering_none_values(
-                pii_classes=pii_classes,
-                num_targets=num_targets,
-                candidate_size=candidate_size,
-                sampling_rate=sampling_rate,
-                regex_expressions=regex_expressions,
-            ),
-            "dataset": Helpers.construct_dict_filtering_none_values(column_name=pii_ref_column),
-            "model": Helpers.construct_dict_filtering_none_values(
-                base_model=base_model,
-            ),
-        }
-
-        return Test.create_test_with_grid(
-            common_attack_config=common_attack_config,
-            grid=grid,
-            request=self._state.request,
-            name=name,
-            model_key=model_key,
-            dataset_id=dataset_id,
-            test_type="pii_reconstruction",
-            gpu=gpu,
-        )
-
     def create_rag_hallucination_test(  # pylint: disable=dangerous-default-value
         self,
         name: str,
@@ -573,7 +555,6 @@ class DynamoFL:
         memorization_granularity: str,
         sampling_rate: int,
         is_finetuned: bool,
-        base_model: Optional[str] = None,
         title: Optional[str] = None,
         title_column: Optional[str] = None,
         text_column: Optional[str] = None,
@@ -591,7 +572,6 @@ class DynamoFL:
             sampling_rate (int): The number of times we prompt the model during a test.
             is_finetuned (bool): Whether the model is finetuned or not; determines
                 whether to generate the fine-tuned or the base model report
-            base_model (Optional[str]): Base model to use for the attack
             title (Optional[str]): Title to use for the attack
             title_column (Optional[str]): Title column to use for the attack
             text_column (Optional[str]): Text column to use for the attack
@@ -607,9 +587,6 @@ class DynamoFL:
                 source=source,
                 is_finetuned=is_finetuned,
             ),
-            "model": Helpers.construct_dict_filtering_none_values(
-                base_model=base_model,
-            ),
             "dataset": Helpers.construct_dict_filtering_none_values(
                 title=title,
                 title_column=title_column,
@@ -633,7 +610,6 @@ class DynamoFL:
         name: str,
         model_key: str,
         gpu: Optional[GPUSpecification] = None,
-        base_model: Optional[str] = None,
         sampling_rate: Optional[int] = None,
         grid: List[Dict[str, List[Union[str, float, int]]]] = [{}],
     ) -> TestEntity:
@@ -642,7 +618,6 @@ class DynamoFL:
         Args:
             name (str): Name of the test
             model_key (str): Key of the model to be tested
-            base_model (Optional[str]): Base model to use for the attack
             sampling_rate (int): The number of times we prompt the model during a test.
             gpu (GPUSpecification): GPU specification
         Returns:
@@ -650,7 +625,6 @@ class DynamoFL:
         """
         common_attack_config = {
             "attack": Helpers.construct_dict_filtering_none_values(sampling_rate=sampling_rate),
-            "model": Helpers.construct_dict_filtering_none_values(base_model=base_model),
         }
         if gpu is None:
             if self.get_model(model_key).type == "REMOTE":
@@ -741,7 +715,6 @@ class DynamoFL:
             name (str): Name of the test
             model_key (str): Key of the model to be tested
             gpu (GPUSpecification): GPU specification
-            base_model (Optional[str]): Base model to use for the attack
         Returns:
             TestEntity: TestEntity object
         """
@@ -822,6 +795,63 @@ class DynamoFL:
             gpu=gpu,
         )
 
+    # Commenting out for now as it's not enabled in any release yet
+    # def create_policy_jailbreak_test(  # pylint: disable=dangerous-default-value
+    #     self,
+    #     name: str,
+    #     model_key: str,
+    #     gpu: Optional[GPUSpecification] = None,
+    #     dataset_id: Optional[str] = None,
+    #     grid: List[Dict[str, List[Union[str, float, int]]]] = [{}],
+    #     **kwargs
+    # ) -> TestEntity:
+    #     """Create a policy jailbreak test on a model
+
+    #     Args:
+    #         name (str): Name of the test
+    #         model_key (str): Key of the model to be tested
+    #         gpu (GPUSpecification): GPU specification
+    #         dataset_id (str): Id of the dataset to be used. If not provided,
+    #             the test will default to the v0 dataset, which is a small
+    #             dataset with 50 prompts for testing purposes:
+    #             https://github.com/patrickrchao/JailbreakingLLMs/blob/main/data/harmful_behaviors_custom.csv
+    #             If using a custom dataset, ensure that the dataset has the following columns:
+    #             - "goal": the prompt
+    #             - "category": the category of the prompt
+    #             - "shortened_prompt": the goal column shortened to 1-2 words
+    #                 (used for encoding attack and ascii art attack)
+    #             - "gcg": the prompt that includes the gcg suffix
+    #     Returns:
+    #         TestEntity: TestEntity object
+    #     """
+    #     if gpu is None:
+    #         if self.get_model(model_key).type == "REMOTE":
+    #             gpu = GPUConfig(gpu_type=GPUType.A10G, gpu_count=1)
+    #         else:
+    #             raise ValueError(
+    #                 "Jailbreaking tests on local models require specifying a GPUConfig that matches the model."
+    #             )
+
+    #     # fast_mode (bool): Whether to use fast mode for the attack. Reduces
+    #     # sampling_rate for each attack to 10.
+    #     # Defaults to False; only use fast mode for internal
+    #     # testing purposes.
+    #     fast_mode = kwargs.get("fast_mode", False)
+    #     common_attack_config = {
+    #         "attack": Helpers.construct_dict_filtering_none_values(fast_mode=fast_mode),
+    #     }
+
+    #     return Test.create_test_with_grid(  # pylint: disable=unexpected-keyword-arg
+    #         common_attack_config=common_attack_config,
+    #         grid=grid,
+    #         request=self._state.request,
+    #         name=name,
+    #         model_key=model_key,
+    #         dataset_id=dataset_id,
+    #         test_type="policy_jailbreak",
+    #         gpu=gpu,
+    #     )
+
     def create_prompt_extraction_test(  # pylint: disable=dangerous-default-value
         self,
         name: str,
@@ -961,35 +991,52 @@ class DynamoFL:
             api_key=api_key,
         )
 
-    def create_guardrail_evaluation_test(  # pylint: disable=dangerous-default-value
+    def create_system_policy_compliance_test(  # pylint: disable=dangerous-default-value
         self,
         name: str,
-        benchmark_type: Literal["guardrail", "target", "guardrail_and_target"],
-        dynamoguard_policy_ids: Optional[List[str]] = None,
+        applied_dynamoguard_policies: Optional[List[str]] = None,
+        evaluated_dynamoguard_policies: Optional[List[str]] = None,
+        dynamoguard_endpoint: Optional[str] = None,
+        dynamoguard_api_key: Optional[str] = None,
         model_key: Optional[str] = None,
         gpu: Optional[GPUSpecification] = None,
-        perturbation_types: Optional[List[str]] = None,
+        enable_perturbations: bool = True,
+        perturbation_methods: List[
+            Literal[
+                "rewording",
+                "common_misspelling",
+                "leet_letters",
+                "random_upper",
+            ]
+        ] = [
+            "rewording",
+            "common_misspelling",
+            "leet_letters",
+            "random_upper",
+        ],
         grid: List[Dict[str, List[Union[str, float, int]]]] = [{}],
         **kwargs
     ) -> TestEntity:
-        """Create guardrail benchmark test.
+        """Create System Policy Compliance benchmark test. Evaluate compliance of AI system with
+        applied and evaluated dynamoguard policies and associated benchmark
+        datasets / policy descriptions.
         Args:
             name (str): Name of the test
-            benchmark_type (Literal["guardrail", "target", "guardrail_and_target"]): Type of guardrail benchmark test to run.
-            dynamoguard_policy_ids (List[str]): List of DynamoGuard policy IDs.
+            applied_dynamoguard_policies (List[str]): List of DynamoGuard policy IDs.
+                These guardrail models will be applied and evaluated.
+            evaluated_dynamoguard_policies (List[str]): List of DynamoGuard policy IDs.
+                These guardrail models will only evaluated.
+            dynamoguard_endpoint (str): Endpoint for the DynamoGuard policies. This
+                should be the analyze endpoint and end with "v1/moderation/analyze/".
+            dynamoguard_api_key (str): API key for the DynamoGuard policies.
             model_key (str): Key of the target model
             gpu (Optional[GPUSpecification]): GPU specification.
                 Defaults to None.
-            fast_mode (bool): Whether to use fast mode for the attack. Reduces
-                sampling_rate to 10. Defaults to False; only use fast
-                mode for internal testing purposes.
-            text_variation_methods (List[Literal["original", "extra_spacing", "word_substitution"]]):
-                Methods to modify input text for testing. Options:
-                - 'original': No modifications (keeps original text)
-                - 'extra_spacing': Adds random spaces
-                - 'word_substitution': Replaces words with synonyms
-                Multiple methods can be selected. Defaults to None, which runs the test with just ["original"], which
-                is not perturbed.
+            enable_perturbations (bool): Defaulted to True; perturbations
+                will run by default.
+            perturbation_methods (List[Literal[...]]): If enable_perturbations
+                is True, these perturbation_methods will run. By default,
+                the full set of perturbations is applied.
 
         Returns:
             TestEntity: TestEntity object
@@ -997,23 +1044,32 @@ class DynamoFL:
         # fast_mode (bool): Whether to use fast mode for the attack. Reduces
         #     sampling_rate to 10. Defaults to False; only use fast
         #     mode for internal testing purposes.
-        if benchmark_type == "guardrail":
-            if dynamoguard_policy_ids is None:
-                raise ValueError("dynamoguard_policy_ids is required for guardrail test")
-            if model_key is not None:
-                raise ValueError("unexpected model_key for guardrail test type")
-        elif benchmark_type in ["target", "guardrail_and_target"]:
-            if model_key is None:
-                raise ValueError("model_key is required for target test")
-            if dynamoguard_policy_ids is None:
-                raise ValueError("dynamoguard_policy_ids is required for guardrail_and_target test")
+        if model_key is None:
+            raise ValueError("model_key is required.")
+        if applied_dynamoguard_policies is None and evaluated_dynamoguard_policies is None:
+            raise ValueError(
+                "Either applied_dynamoguard_policies or evaluated_dynamoguard_policies "
+                "must be provided for this test."
+            )
+
+        if gpu is None:
+            if self.get_model(model_key).type == "REMOTE":
+                gpu = GPUConfig(gpu_type=GPUType.A10G, gpu_count=1)
+            else:
+                raise ValueError(
+                    "System Policy Compliance tests on local models require specifying a GPUConfig that matches the model."
+                )
+
         fast_mode = kwargs.get("fast_mode", False)
         common_attack_config = {
             "attack": Helpers.construct_dict_filtering_none_values(
-                benchmark_type=benchmark_type,
-                dynamoguard_policy_ids=dynamoguard_policy_ids,
-                perturbation_types=perturbation_types,
+                applied_dynamoguard_policies=applied_dynamoguard_policies,
+                evaluated_dynamoguard_policies=evaluated_dynamoguard_policies,
+                dynamoguard_endpoint=dynamoguard_endpoint,
+                dynamoguard_api_key=dynamoguard_api_key,
                 fast_mode=fast_mode,
+                enable_perturbations=enable_perturbations,
+                perturbation_methods=perturbation_methods,
             ),
         }
 
@@ -1021,7 +1077,6 @@ class DynamoFL:
             request=self._state.request,
             name=name,
             model_key=model_key,
-            # question: is it ok to have None dataset_id?
             dataset_id=None,
             test_type="guardrail_benchmark",
             common_attack_config=common_attack_config,
@@ -1114,29 +1169,29 @@ class DynamoFL:
             peft_config_path=None,
         )
 
-    def create_azure_openai_model(
+    def create_azure_model(
         self,
         name: str,
         api_instance: str,
         api_key: str,
-        api_version: str,
         model_endpoint: str,
+        api_version: Optional[str] = None,
         key: Optional[str] = None,
     ) -> RemoteModelEntity:
-        """Creates azure openai model
+        """Creates Azure AI (along with Azure OpenAI) model
 
         Args:
             name (str): Name of the model to be created
-            api_instance (str): Azure openai api instance
-            api_key (str): Azure openai api key
-            api_version (str): Azure openai api version
-            model_endpoint (str): Azure openai model endpoint to use
+            api_instance (str): Azure AI api instance
+            api_key (str): Azure AI api key
+            api_version (str): Azure AI api version
+            model_endpoint (str): Azure AI model endpoint to use
             key (str): Unique key for the model
 
         Returns:
             RemoteModelEntity: RemoteModelEntity object
         """
-        return remote_model.RemoteModel.create_azure_openai_model(
+        return remote_model.RemoteModel.create_azure_model(
             request=self._state.request,
             name=name,
             api_instance=api_instance,
@@ -1146,6 +1201,36 @@ class DynamoFL:
             key=key,
         )
 
+    def create_lambdalabs_model(
+        self,
+        name: str,
+        api_instance: str,
+        api_key: str,
+        model_endpoint: str,
+        key: Optional[str] = None,
+    ) -> RemoteModelEntity:
+        """Creates LambdaLabs model
+
+        Args:
+            name (str): Name of the model to be created
+            api_instance (str): LambdaLabs api instance
+            api_key (str): LambdaLabs api key
+            api_version (str): LambdaLabs api version
+            model_endpoint (str): LambdaLabs model endpoint to use
+            key (str): Unique key for the model
+
+        Returns:
+            RemoteModelEntity: RemoteModelEntity object
+        """
+        return remote_model.RemoteModel.create_lambdalabs_model(
+            request=self._state.request,
+            name=name,
+            api_instance=api_instance,
+            api_key=api_key,
+            model_endpoint=model_endpoint,
+            key=key,
+        )
+
     def create_openai_model(
         self,
         name: str,
@@ -1172,6 +1257,84 @@ class DynamoFL:
             key=key,
         )
 
+    def create_anthropic_model(
+        self,
+        name: str,
+        api_instance: str,
+        api_key: str,
+        key: Optional[str] = None,
+    ) -> RemoteModelEntity:
+        """Creates Anthropic model
+
+        Args:
+            name (str): Name of the model to be created
+            api_instance (str): Anthropic api instance
+            api_key (str): Anthropic api key
+            key (str): Unique key for the model
+
+        Returns:
+            RemoteModelEntity: RemoteModelEntity object
+        """
+        return remote_model.RemoteModel.create_anthropic_model(
+            request=self._state.request,
+            name=name,
+            api_instance=api_instance,
+            api_key=api_key,
+            key=key,
+        )
+
+    def create_mistral_model(
+        self,
+        name: str,
+        api_instance: str,
+        api_key: str,
+        key: Optional[str] = None,
+    ) -> RemoteModelEntity:
+        """Creates Mistral model
+
+        Args:
+            name (str): Name of the model to be created
+            api_instance (str): Mistral api instance
+            api_key (str): Mistral api key
+            key (str): Unique key for the model
+
+        Returns:
+            RemoteModelEntity: RemoteModelEntity object
+        """
+        return remote_model.RemoteModel.create_mistral_model(
+            request=self._state.request,
+            name=name,
+            api_instance=api_instance,
+            api_key=api_key,
+            key=key,
+        )
+
+    def create_togetherai_model(
+        self,
+        name: str,
+        api_instance: str,
+        api_key: str,
+        key: Optional[str] = None,
+    ) -> RemoteModelEntity:
+        """Creates TogetherAI model
+
+        Args:
+            name (str): Name of the model to be created
+            api_instance (str): TogetherAI api instance
+            api_key (str): TogetherAI api key
+            key (str): Unique key for the model
+
+        Returns:
+            RemoteModelEntity: RemoteModelEntity object
+        """
+        return remote_model.RemoteModel.create_togetherai_model(
+            request=self._state.request,
+            name=name,
+            api_instance=api_instance,
+            api_key=api_key,
+            key=key,
+        )
+
     def create_databricks_model(
         self,
         name: str,
@@ -1201,16 +1364,26 @@ class DynamoFL:
     def create_custom_model(
         self,
         name: str,
-        api_key: str,
-        model_endpoint: str,
+        remote_model_endpoint: str,
+        remote_api_auth_config: dict,
+        request_transformation_expression: Optional[str] = None,
+        response_transformation_expression: Optional[str] = None,
+        response_type: Optional[str] = "string",
+        batch_size: Optional[int] = 1,
+        multi_turn_support: Optional[bool] = True,
+        enable_retry: Optional[bool] = False,
         key: Optional[str] = None,
     ) -> RemoteModelEntity:
         """Creates custom model
 
         Args:
             name (str): Name of the model to be created
-            api_key (str): api token
-            model_endpoint (str): model endpoint to use
+            remote_model_endpoint (str): Endpoint for the remote model
+            remote_api_auth_config (dict): Authentication configuration for the remote API
+            request_transformation_expression (Optional[str]): Expression for request transformation
+            response_transformation_expression (Optional[str]): Expression for response transformation
+            batch_size (int): Size of the batch for requests
+            multi_turn_support (bool): Indicates if the interaction is single-turn
             key (str): Unique key for the model
 
         Returns:
@@ -1219,8 +1392,14 @@ class DynamoFL:
         return remote_model.RemoteModel.create_custom_model(
             request=self._state.request,
             name=name,
-            api_key=api_key,
-            model_endpoint=model_endpoint,
+            remote_model_endpoint=remote_model_endpoint,
+            remote_api_auth_config=remote_api_auth_config,
+            request_transformation_expression=request_transformation_expression,
+            response_transformation_expression=response_transformation_expression,
+            response_type=response_type,
+            batch_size=batch_size,
+            multi_turn_support=multi_turn_support,
+            enable_retry=enable_retry,
             key=key,
         )
 
